# Dearning

<p align="center">
  <img src="https://raw.githubusercontent.com/maker-games/Logo-Dearning/main/ChatGPT_Image_17_Nov_2025__16.56.31-removebg-preview.png"
 width=195">
</p>

![Downloads](https://static.pepy.tech/personalized-badge/dearning?period=total&units=INTERNATIONAL_SYSTEM&left_color=BLUE&right_color=LIGHTGREY&left_text=downloads)
![PyPI Version](https://img.shields.io/pypi/v/dearning)
![PyPI - Python Version](https://img.shields.io/pypi/pyversions/dearning)
![PyPI - Wheel](https://img.shields.io/pypi/wheel/dearning)
![PyPI - Implementation](https://img.shields.io/pypi/implementation/dearning)
![License](https://img.shields.io/pypi/l/dearning)
![Pure](https://img.shields.io/badge/pure%20python-yes-green)
![Stars](https://img.shields.io/github/stars/maker-games/Logo-Dearning)
![Visitors](https://komarev.com/ghpvc/?username=maker-games&label=Visitors&color=blue&style=flat)
![Lint](https://img.shields.io/badge/lint-passing-brightgreen)
![Rev](https://img.shields.io/badge/status-revolutionary-orange)

**Dearning** is a community-developed Python library for deep learning and pure Python machine learning. It's designed as a lightweight AI framework, making it suitable for a wide range of devices.
